@@ -1,3 +1,4 @@
+import textwrap
 from dataclasses import dataclass, fields
 from typing import BinaryIO, ClassVar, Dict, List, Optional, TYPE_CHECKING, Tuple, Union
 
@@ -198,7 +199,15 @@ class Config:
         if "external_outputs" not in module.model_class.type_mapping:
             raise ValueError("Model must have at least one outport.")
         if "instance_parameters" not in module.model_class.type_mapping:
-            raise ValueError("Model must have at least one parameter.")
+            raise ValueError(textwrap.dedent("""
+                Model must have at least one parameter.
+                Environemt without parameters is most likely a modeling mistake.
+                Make sure that your tunable parameters are
+                    1. in model workspace
+                    2. of Simulink Parameter type
+                    3. with Argument checkbox checked
+                For more information, see documentation.
+                """).strip())
 
         if self.use_gym:
             # Gym compatibility check
