@@ -149,7 +149,7 @@ namespace slxpy::env::space
     }
 
     void slxpy_bind_space(::pybind11::module_& s) {
-        pybind11::class_<Discrete> Discrete_PB(s, "Discrete");
+        pybind11::class_<Discrete> Discrete_PB(s, "Discrete", pybind11::module_local());
         Discrete_PB
             .def_readonly("n", &Discrete::n)
             .def("contains", &Discrete::contains)
@@ -165,7 +165,7 @@ namespace slxpy::env::space
             ));
         Discrete_PB.attr("dtype") = pybind11::dtype::of<Discrete::value_type>();
 
-        pybind11::class_<MultiDiscrete> MultiDiscrete_PB(s, "MultiDiscrete");
+        pybind11::class_<MultiDiscrete> MultiDiscrete_PB(s, "MultiDiscrete", pybind11::module_local());
         MultiDiscrete_PB
             .def_readonly("nvec", &MultiDiscrete::nvec)
             .def("contains", &MultiDiscrete::contains)
@@ -181,7 +181,7 @@ namespace slxpy::env::space
             ));
         MultiDiscrete_PB.attr("dtype") = pybind11::dtype::of<MultiDiscrete::value_type>();
 
-        pybind11::class_<MultiBinary> MultiBinary_PB(s, "MultiBinary");
+        pybind11::class_<MultiBinary> MultiBinary_PB(s, "MultiBinary", pybind11::module_local());
         MultiBinary_PB
             .def_readonly("n", &MultiBinary::n)
             .def("contains", &MultiBinary::contains)
@@ -219,7 +219,7 @@ namespace slxpy::env::space
         using Box = slxpy::env::space::Box<T>;
         using npa = pybind11::array_t<T, pybind11::array::c_style | pybind11::array::forcecast>;
 
-        pybind11::class_<Box> Box_PB(s, slxpy_get_box_typename<T>());
+        pybind11::class_<Box> Box_PB(s, slxpy_get_box_typename<T>(), pybind11::module_local());
         auto contains = [](Box& self, npa array) {
             if (static_cast<size_t>(array.ndim()) != self.shape.size()) {
                 return false;
@@ -413,17 +413,17 @@ namespace slxpy::env::spec {
     };
 
     void slxpy_bind_spec(::pybind11::module_& s) {
-        pybind11::enum_<IndexingMode> IndexingMode_PB(s, "IndexingMode");
+        pybind11::enum_<IndexingMode> IndexingMode_PB(s, "IndexingMode", pybind11::module_local());
         IndexingMode_PB
             .value("PRESERVE_EMPTY", IndexingMode::PRESERVE_EMPTY)
             .value("PRESERVE_FILL", IndexingMode::PRESERVE_FILL)
             .value("COMPRESS", IndexingMode::COMPRESS);
 
-        pybind11::enum_<ActionRepeatMode> ActionRepeatMode_PB(s, "ActionRepeatMode");
+        pybind11::enum_<ActionRepeatMode> ActionRepeatMode_PB(s, "ActionRepeatMode", pybind11::module_local());
         ActionRepeatMode_PB
             .value("SUM_BREAK", ActionRepeatMode::SUM_BREAK);
 
-        pybind11::class_<EnvSpec> EnvSpec_PB(s, "EnvSpec");
+        pybind11::class_<EnvSpec> EnvSpec_PB(s, "EnvSpec", pybind11::module_local());
         EnvSpec_PB
             .def(pybind11::init([] (
                     std::string id,
