@@ -16,8 +16,8 @@ void slxpy_init_simulink(::pybind11::module_ &m) {
 
     #ifdef ZERO_CROSSING_TYPES_H
         // From zero_crossing_types.h
-        auto ZCDirection_pb = pybind11::enum_<ZCDirection>(sl, "ZCDirection", "Trigger directions: falling, either, and rising");
-        auto ZCEventType_pb = pybind11::enum_<ZCEventType>(sl, "ZCEventType", "Current state of a trigger signal");
+        auto ZCDirection_pb = pybind11::enum_<ZCDirection>(sl, "ZCDirection", "Trigger directions: falling, either, and rising", pybind11::module_local());
+        auto ZCEventType_pb = pybind11::enum_<ZCEventType>(sl, "ZCEventType", "Current state of a trigger signal", pybind11::module_local());
         ZCDirection_pb
             .value("FALLING_ZERO_CROSSING", FALLING_ZERO_CROSSING)
             .value("ANY_ZERO_CROSSING", ANY_ZERO_CROSSING)
@@ -63,20 +63,20 @@ void slxpy_init_simulink(::pybind11::module_ &m) {
         sl.def("rtIsNaNF", rtIsNaNF, "value"_a);
 
         using BigEndianIEEEDouble_words_T = decltype(BigEndianIEEEDouble::words);
-        pybind11::class_<BigEndianIEEEDouble> BigEndianIEEEDouble_pb (sl, "BigEndianIEEEDouble");
-        pybind11::class_<BigEndianIEEEDouble_words_T> BigEndianIEEEDouble_words_T_pb (BigEndianIEEEDouble_pb, "BigEndianIEEEDouble_words_T");
+        pybind11::class_<BigEndianIEEEDouble> BigEndianIEEEDouble_pb (sl, "BigEndianIEEEDouble", pybind11::module_local());
+        pybind11::class_<BigEndianIEEEDouble_words_T> BigEndianIEEEDouble_words_T_pb (BigEndianIEEEDouble_pb, "BigEndianIEEEDouble_words_T", pybind11::module_local());
         BigEndianIEEEDouble_pb.def_readwrite("words", &BigEndianIEEEDouble::words);
         BigEndianIEEEDouble_words_T_pb.def_readwrite("wordH", &BigEndianIEEEDouble_words_T::wordH).def_readwrite("wordL", &BigEndianIEEEDouble_words_T::wordL);
 
         using LittleEndianIEEEDouble_words_T = decltype(LittleEndianIEEEDouble::words);
-        pybind11::class_<LittleEndianIEEEDouble> LittleEndianIEEEDouble_pb (sl, "LittleEndianIEEEDouble");
-        pybind11::class_<LittleEndianIEEEDouble_words_T> LittleEndianIEEEDouble_words_T_pb (LittleEndianIEEEDouble_pb, "LittleEndianIEEEDouble_words_T");
+        pybind11::class_<LittleEndianIEEEDouble> LittleEndianIEEEDouble_pb (sl, "LittleEndianIEEEDouble", pybind11::module_local());
+        pybind11::class_<LittleEndianIEEEDouble_words_T> LittleEndianIEEEDouble_words_T_pb (LittleEndianIEEEDouble_pb, "LittleEndianIEEEDouble_words_T", pybind11::module_local());
         LittleEndianIEEEDouble_pb.def_readwrite("words", &LittleEndianIEEEDouble::words);
         LittleEndianIEEEDouble_words_T_pb.def_readwrite("wordH", &LittleEndianIEEEDouble_words_T::wordH).def_readwrite("wordL", &LittleEndianIEEEDouble_words_T::wordL);
 
         using IEEESingle_words_T = decltype(IEEESingle::wordL);
-        pybind11::class_<IEEESingle> IEEESingle_pb (sl, "IEEESingle");
-        pybind11::class_<IEEESingle_words_T> IEEESingle_words_T_pb (IEEESingle_pb, "IEEESingle_words_T");
+        pybind11::class_<IEEESingle> IEEESingle_pb (sl, "IEEESingle", pybind11::module_local());
+        pybind11::class_<IEEESingle_words_T> IEEESingle_words_T_pb (IEEESingle_pb, "IEEESingle_words_T", pybind11::module_local());
         IEEESingle_pb.def_readwrite("words", &IEEESingle::wordL);
         IEEESingle_words_T_pb.def_readwrite("wordLreal", &IEEESingle_words_T::wordLreal).def_readwrite("wordLuint", &IEEESingle_words_T::wordLuint);
     #endif
@@ -90,7 +90,7 @@ void slxpy_init_simulink(::pybind11::module_ &m) {
 
     #ifdef solver_zc_hpp_
         // From solver_zc.h
-        auto slZcSignalType_pb = pybind11::enum_<slZcSignalType>(sl, "slZcSignalType", "slZcSignalType");
+        auto slZcSignalType_pb = pybind11::enum_<slZcSignalType>(sl, "slZcSignalType", "slZcSignalType", pybind11::module_local());
         slZcSignalType_pb
             .value("SL_ZCS_TYPE_CONT", SL_ZCS_TYPE_CONT)
             .value("SL_ZCS_TYPE_DISC", SL_ZCS_TYPE_DISC)
